@@ -7,21 +7,22 @@
 name = 'Eric-Tools'
 __title__ = 'tools'
 __description__ = 'Python HTTP for Humans.'
-__version__ = "1.1.6"
+__version__ = "1.1.7"
 __author__ = 'Eric'
 __doc__ = ["Python Daily Development Tools"]
 __url__ = "https://github.com/Eric-jxl/Tools"
 __license__ = "MIT"
 
-from . import exception_class
-from . import resize_image
-from . import logger
+import exception_class
+import resize_image
+import logger
 import ip
-from . import encryption_classmethod
-from . import pgsql
-from . import sftp
+import encryption_classmethod
+import pgsql
+import sftp
 import readconfig
 import send_email
 import jwt_encrypt
 import convert_json
 import Abstract
+import decorator
